# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.cohorts_api import CohortsApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestCohortsApi(unittest.TestCase):
    """CohortsApi unit test stubs"""

    def setUp(self):
        self.api = CohortsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cohort_controller_query(self):
        """Test case for cohort_controller_query

        Submit Cohort Queries  # noqa: E501
        """
        pass

    def test_cohort_controller_sql(self):
        """Test case for cohort_controller_sql

        Generate SQL queries for cohort  # noqa: E501
        """
        pass

    def test_create_many_base_cohort_controller_cohort(self):
        """Test case for create_many_base_cohort_controller_cohort

        Create many Cohort  # noqa: E501
        """
        pass

    def test_create_one_base_cohort_controller_cohort(self):
        """Test case for create_one_base_cohort_controller_cohort

        Create one Cohort  # noqa: E501
        """
        pass

    def test_delete_one_base_cohort_controller_cohort(self):
        """Test case for delete_one_base_cohort_controller_cohort

        Delete one Cohort  # noqa: E501
        """
        pass

    def test_get_many_base_cohort_controller_cohort(self):
        """Test case for get_many_base_cohort_controller_cohort

        Retrieve many Cohort  # noqa: E501
        """
        pass

    def test_get_one_base_cohort_controller_cohort(self):
        """Test case for get_one_base_cohort_controller_cohort

        Retrieve one Cohort  # noqa: E501
        """
        pass

    def test_replace_one_base_cohort_controller_cohort(self):
        """Test case for replace_one_base_cohort_controller_cohort

        Replace one Cohort  # noqa: E501
        """
        pass

    def test_update_one_base_cohort_controller_cohort(self):
        """Test case for update_one_base_cohort_controller_cohort

        Update one Cohort  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
